@@ -121,11 +121,24 @@ int audio_feed_jack_samplerate_request(struct threads_info *ti, struct universal
    return SUCCEEDED;
    }
 
+static char *str_join(const char *s1, const char *s2)
+   {
+   size_t l = strlen(s1) + strlen(s2) + 1;
+   char *s;
+   
+   if (!(s = malloc(l)))
+      {
+      fprintf(stderr, "malloc failure");
+      return NULL;
+      }
+
+   snprintf(s, l, "%s%s", s1, s2);
+   return s;
+   }
+
 struct audio_feed *audio_feed_init(struct threads_info *ti)
    {
    struct audio_feed *self;
-   size_t l;
-   char *sc_client_name, *mx_client_name;
 
    if (!(self = calloc(1, sizeof (struct audio_feed))))
       {
@@ -133,31 +146,15 @@ struct audio_feed *audio_feed_init(struct threads_info *ti)
       return NULL;
       }
       
-   mx_client_name = getenv("mx_client_id");
-   sc_client_name = getenv("sc_client_id");
-   l = strlen(sc_client_name) + 11;
-   self->mx_port_l = malloc(l);
-   self->mx_port_r = malloc(l);
-   --l;
-   self->sc_port_l = malloc(l);
-   self->sc_port_r = malloc(l);
-   ++l;
-   
-   if (self->mx_port_l && self->mx_port_r && self->sc_port_l && self->sc_port_r)
-      {
-      snprintf(self->mx_port_l, l, "%s:%s", mx_client_name, "str_out_l");
-      snprintf(self->mx_port_r, l, "%s:%s", mx_client_name, "str_out_r");
-      --l;
-      snprintf(self->sc_port_l, l, "%s:%s", sc_client_name, "str_in_l");
-      snprintf(self->sc_port_r, l, "%s:%s", sc_client_name, "str_in_r");
-      }
-   else
-      {
-      fprintf(stderr, "malloc failure\n");
+   self->mx_port_l = str_join(getenv("mx_client_id"), ":str_out_l");
+   self->mx_port_r = str_join(getenv("mx_client_id"), ":str_out_r");
+   self->sc_port_l = str_join(getenv("sc_client_id"), ":str_in_l");
+   self->sc_port_r = str_join(getenv("sc_client_id"), ":str_in_r");
+
+   if (!(self->mx_port_l && self->mx_port_r && self->sc_port_l && self->sc_port_r))
       return NULL;
-      }
       
-   if (!(self->jack_client_name = strdup(sc_client_name)))
+   if (!(self->jack_client_name = strdup(getenv("sc_client_id"))))
       {
       fprintf(stderr, "audio_feed_init: malloc failure\n");
       return NULL;
@@ -168,7 +165,7 @@ struct audio_feed *audio_feed_init(struct threads_info *ti)
    jack_set_info_function(custom_jack_info_callback);
 #endif
 
-   if (!(self->jack_h = jack_client_open(self->jack_client_name, JackUseExactName | JackServerName, NULL, getenv("IDJC_JACK_SERVER"))))
+   if (!(self->jack_h = jack_client_open(self->jack_client_name, JackUseExactName | JackServerName, NULL, getenv("jack_server_name"))))
       {
       fprintf(stderr, "audio_feed_init: creation of a new jack client failed\nthis could be due to jackd having not been started or another instance of idjcsourceclient is currently running\n");
       return NULL;
@@ -199,6 +196,6 @@ void audio_feed_destroy(struct audio_feed *self)
    free(self->mx_port_l);
    free(self->mx_port_r);
    free(self->sc_port_l);
-   free(self->mx_port_r);
+   free(self->sc_port_r);
    free(self);
    }
