@@ -56,7 +56,7 @@
 /* playlength of ring buffer contents */
 #define RB_SIZE 10.0
 /* number of samples in the fade (ring) buffer */
-#define FB_SIZE (RB_SIZE * sr)
+#define FB_SIZE (size_t)(RB_SIZE * sr)
 /* number of bytes in the MIDI queue buffer */
 #define MIDI_QUEUE_SIZE 1024
 
@@ -68,7 +68,7 @@
 typedef jack_default_audio_sample_t sample_t;
 
 /* values of the volume sliders in the GUI */
-int volume, volume2, crossfade, jinglesvolume, interludevol, mixbackvol, crosspattern;
+int volume, volume2, crossfade, jinglesvolume, jinglesvolume2, interludevol, mixbackvol, crosspattern;
 /* back and forth status indicators re. jingles */
 int jingles_playing, jingles_audio_f;
 /* used for gapless playback to indicate an almost empty buffer */
@@ -76,14 +76,12 @@ int left_audio_runout = 0, right_audio_runout = 0;
 /* the main-player unmute buttons */
 int left_stream = 1, left_audio = 1, right_stream = 1, right_audio = 1;
 /* status variables for the button cluster in lower right of main window */
-int aux_on, mic_on, mixermode = NO_PHONE;
-/* TRUE when the transitioning between on and off */
-int aux_flux;
+int mic_on, mixermode = NO_PHONE;
 /* simple mixer mode: uses less space on the screen and less cpu as well */
 int simple_mixer;
 /* currentvolumes are used to implement volume smoothing */
-int current_volume, current_volume2, current_jingles_volume, current_interlude_volume,
-    current_crossfade, currentmixbackvol, current_crosspattern; 
+int current_volume, current_volume2, current_jingles_volume, current_jingles_volume2, 
+    current_interlude_volume, current_crossfade, currentmixbackvol, current_crosspattern;
 /* the id. number microphone filter we are using */
 int mic_filter;
 /* value of the stream mon. button */
@@ -93,8 +91,8 @@ int eot_alarm_set = 0;
 /* set when end of track alarm is active */
 int eot_alarm_f = 0;
 /* threshold values for a premature indicator that a player is about to finish */
-int jingles_samples_cutoff;
-int player_samples_cutoff;
+unsigned jingles_samples_cutoff;
+unsigned player_samples_cutoff;
 /* the number of samples processed this song - used to calculate the player progress bars */
 int left_samples_total, right_samples_total;
 /* used to implement interlude player fade in/out: true when playing a track */
@@ -122,7 +120,7 @@ struct mic **mics;
 /* flag for mp3 decode capability */
 int have_mad;
 /* size of the fade buffer */
-int fb_size;
+size_t fb_size;
 /* peakfilter handles for stream peak */
 struct peakfilter *str_pf_l, *str_pf_r;
 
@@ -147,13 +145,13 @@ float current_dj_audio_level = 0.0;
 
 struct compressor stream_limiter =
    {
-   0.0, -0.05, -0.2, INFINITY, 1, 1.0F/4000.0F, 0.0, 0.0, 1, 1, 0.0, 0.0
+   0.0, -0.05, -0.2, INFINITY, 1, 1.0F/4000.0F, 0.0, 0.0, 1, 1, 0.0, 0.0, 0.0
    }, audio_limiter =
    {
-   0.0, -0.05, -0.2, INFINITY, 1, 1.0F/4000.0F, 0.0, 0.0, 1, 1, 0.0, 0.0
+   0.0, -0.05, -0.2, INFINITY, 1, 1.0F/4000.0F, 0.0, 0.0, 1, 1, 0.0, 0.0, 0.0
    }, phone_limiter =
    {
-   0.0, -0.05, -0.2, INFINITY, 1, 1.0F/4000.0F, 0.0, 0.0, 1, 1, 0.0, 0.0
+   0.0, -0.05, -0.2, INFINITY, 1, 1.0F/4000.0F, 0.0, 0.0, 1, 1, 0.0, 0.0, 0.0
    };
 
 struct normalizer str_normalizer =
@@ -180,8 +178,6 @@ sample_t ip_lc_strf = 1.0, ip_rc_strf = 1.0, ip_lc_audf = 0.0, ip_rc_audf = 0.0;
          
 /* used to apply the stereo mix of the microphones */
 sample_t mic_l_lc = 1.0, mic_l_rc = 0.0, mic_r_lc = 0.0, mic_r_rc = 1.0;
-/* aux input gain factor - typically 1.0=on or 0.0=off */
-sample_t aux_lc = 0.0, aux_rc = 0.0;
 /* media player mixback level for when in RedPhone mode */
 sample_t mb_lc_aud = 1.0, mb_rc_aud = 1.0;
 sample_t current_headroom;      /* the amount of mic headroom being applied */
@@ -196,8 +192,6 @@ jack_port_t *dspin_left_port;
 jack_port_t *dspin_right_port;
 jack_port_t *stream_left_port;
 jack_port_t *stream_right_port;
-jack_port_t *aux_left_channel;
-jack_port_t *aux_right_channel;
 jack_port_t *phone_left_send;   /* used for VOIP */
 jack_port_t *phone_right_send;
 jack_port_t *phone_left_recv;
@@ -218,7 +212,7 @@ struct xlplayer *plr_l, *plr_r, *plr_j, *plr_i; /* pipe reader instance stucture
 /* these are set in the parse routine - the contents coming from the GUI */
 char *mixer_string, *compressor_string, *gate_string, *microphone_string, *item_index;
 char *normalizer_string, *new_mic_string;
-char *micl, *micr, *auxl, *auxr, *midi, *audl, *audr, *strl, *strr, *action;
+char *micl, *micr, *midi, *audl, *audr, *strl, *strr, *action;
 char *target_port_name;
 char *dol, *dor, *dil, *dir;
 char *oggpathname, *sndfilepathname, *avformatpathname, *speexpathname, *speextaglist, *speexcreatedby;
@@ -226,47 +220,49 @@ char *playerpathname, *seek_s, *size, *playerplaylist, *loop, *resamplequality;
 char *mic_param, *fade_mode;
 char *rg_db, *headroom;
 char *flag;
+char *channel_mode_string;
+char *use_jingles_vol_2;
 
 /* dictionary look-up type thing used by the parse routine */
 struct kvpdict kvpdict[] = {
-         { "PLRP", &playerpathname },   /* The media-file pathname for playback */
-         { "RGDB", &rg_db },            /* Replay Gain volume level controlled at the player end */
-         { "SEEK", &seek_s },           /* Playback initial seek time in seconds */
-         { "SIZE", &size },             /* Size of the file in seconds */
-         { "PLPL", &playerplaylist },   /* A playlist for the media players */
-         { "LOOP", &loop },             /* play in a loop */
-         { "MIXR", &mixer_string },     /* Control strings */
-         { "COMP", &compressor_string },/* packed full of data */
-         { "GATE", &gate_string },
-         { "MICS", &microphone_string },
-         { "INDX", &item_index },
-         { "NORM", &normalizer_string },
-         { "NMIC", &new_mic_string },
-         { "MIC",  &target_port_name },
-         { "AUXL", &auxl },
-         { "AUXR", &auxr },
-         { "MIDI", &midi },
-         { "AUDL", &audl },
-         { "AUDR", &audr },
-         { "STRL", &strl },
-         { "STRR", &strr },
-         { "DOL", &dol   },
-         { "DOR", &dor   },
-         { "DIL", &dil   },
-         { "DIR", &dir   },
-         { "FADE", &fade_mode },
-         { "OGGP", &oggpathname },
-         { "SPXP", &speexpathname },
-         { "SNDP", &sndfilepathname },
-         { "AVFP", &avformatpathname },
-         { "SPXT", &speextaglist },
-         { "SPXC", &speexcreatedby },
-         { "RSQT", &resamplequality },
-         { "AGCP", &mic_param },
-         { "HEAD", &headroom },
-         { "FLAG", &flag },
-         { "ACTN", &action },                   /* Action to take */
-         { "", NULL }};
+         { "PLRP", &playerpathname, NULL },   /* The media-file pathname for playback */
+         { "RGDB", &rg_db, NULL },            /* Replay Gain volume level controlled at the player end */
+         { "SEEK", &seek_s, NULL },           /* Playback initial seek time in seconds */
+         { "SIZE", &size, NULL },             /* Size of the file in seconds */
+         { "PLPL", &playerplaylist, NULL },   /* A playlist for the media players */
+         { "LOOP", &loop, NULL },             /* play in a loop */
+         { "MIXR", &mixer_string, NULL },     /* Control strings */
+         { "COMP", &compressor_string, NULL },/* packed full of data */
+         { "GATE", &gate_string, NULL },
+         { "MICS", &microphone_string, NULL },
+         { "INDX", &item_index, NULL },
+         { "NORM", &normalizer_string, NULL },
+         { "NMIC", &new_mic_string, NULL },
+         { "MIC",  &target_port_name, NULL },
+         { "MIDI", &midi, NULL },
+         { "AUDL", &audl, NULL },
+         { "AUDR", &audr, NULL },
+         { "STRL", &strl, NULL },
+         { "STRR", &strr, NULL },
+         { "DOL", &dol, NULL   },
+         { "DOR", &dor, NULL   },
+         { "DIL", &dil, NULL   },
+         { "DIR", &dir, NULL   },
+         { "VOL2", &use_jingles_vol_2, NULL },
+         { "FADE", &fade_mode, NULL },
+         { "OGGP", &oggpathname, NULL },
+         { "SPXP", &speexpathname, NULL },
+         { "SNDP", &sndfilepathname, NULL },
+         { "AVFP", &avformatpathname, NULL },
+         { "SPXT", &speextaglist, NULL },
+         { "SPXC", &speexcreatedby, NULL },
+         { "RSQT", &resamplequality, NULL },
+         { "AGCP", &mic_param, NULL },
+         { "HEAD", &headroom, NULL },
+         { "FLAG", &flag, NULL },
+         { "CMOD", &channel_mode_string, NULL },
+         { "ACTN", &action, NULL },                   /* Action to take */
+         { "", NULL, NULL }};
 
 /* the rms filter currently in use */
 struct rms_calc *lm_rms_filter, *rm_rms_filter;
@@ -311,7 +307,8 @@ void handle_mute_button(sample_t *gainlevel, int switchlevel)
 /* update_smoothed_volumes: stuff that gets run once every 32 samples */
 void update_smoothed_volumes()
    {
-   static sample_t vol_rescale = 1.0F, vol2_rescale = 1.0F, jingles_vol_rescale = 1.0F, interlude_vol_rescale = 1.0F;
+   static sample_t vol_rescale = 1.0F, vol2_rescale = 1.0F, jingles_vol_rescale = 1.0F;
+   static sample_t jingles_vol_rescale2 = 1.0F, interlude_vol_rescale = 1.0F;
    static sample_t cross_left = 1.0F, cross_right = 0.0F, mixback_rescale = 1.0F;
    static sample_t lp_listen_mute = 1.0F, rp_listen_mute = 1.0F, lp_stream_mute = 1.0F, rp_stream_mute = 1.0F;
    sample_t mic_target, diff;
@@ -418,6 +415,15 @@ void update_smoothed_volumes()
          current_jingles_volume--;
       jingles_vol_rescale = 1.0F/powf(10.0F,current_jingles_volume/55.0F);
       }
+
+   if (jinglesvolume2 != current_jingles_volume2)
+      {
+      if (jinglesvolume2 > current_jingles_volume2)
+         current_jingles_volume2++;
+      else
+         current_jingles_volume2--;
+      jingles_vol_rescale2 = 1.0F/powf(10.0F,current_jingles_volume2/55.0F);
+      }
       
    /* interlude_autovol rises and falls as and when no media players are playing */
    /* it indicates the playback volume in dB in addition to the one specified by the user */
@@ -466,27 +472,17 @@ void update_smoothed_volumes()
    rp_lc_aud = rp_rc_aud = vol2_rescale * rp_listen_mute;
    lp_lc_str = lp_rc_str = vol_rescale * cross_left * lp_stream_mute;
    rp_lc_str = rp_rc_str = vol2_rescale * cross_right * rp_stream_mute;
-   jp_lc_str = jp_rc_str = jp_lc_aud = jp_rc_aud = jingles_vol_rescale;
+   jp_lc_str = jp_rc_str = jp_lc_aud = jp_rc_aud = (use_jingles_vol_2 && use_jingles_vol_2[0] == '1') ? jingles_vol_rescale2 : jingles_vol_rescale;
    mb_lc_aud = mb_rc_aud = mixback_rescale;
    ip_lc_aud = ip_rc_aud = 0.0F;
    ip_lc_str = ip_rc_str = interlude_vol_rescale;
     
-   mic_target = headroom_db * (mic_on ? -1.0F : 0.0F);
+   mic_target = -headroom_db;
    if ((diff = mic_target - current_headroom))
       {
       current_headroom += diff * 1600.0f / (sr * powf(headroom_db + 10.0f, 0.93f));
-      if (mic_target)
-         {
-         if (diff > -0.00001F)
-            {
-            current_headroom = mic_target;
-            }
-         }
-      else
-         if (diff < 0.0000004F)
-            {
-            current_headroom = 0.0F; 
-            }
+      if (fabsf(diff) < 0.000001F)
+         current_headroom = mic_target;
       }
 
    if (jingles_playing)
@@ -496,39 +492,6 @@ void update_smoothed_volumes()
    dfmod = vol * vol + 1.0F;
    }
 
-/* update_mic_and_aux: provide gradual mute/unmute for aux button */
-void update_mic_and_aux()       /* aux mute/unmute smoothing */
-   {
-   const sample_t onfactor = 0.0006F * 44100.0F / (float)sr;
-   const sample_t offfactor = 0.00028F * 44100.0F / (float)sr;
-   const sample_t upper = 0.999999;     /* these values are to prevent cpu usage going ^^^^ */
-   const sample_t lower = 0.0000004;    /* -120 dB */
-   
-   if (aux_flux)
-      {
-      if (aux_on)
-         {
-         if (aux_lc < upper)
-            aux_lc = aux_rc += (1.0F - aux_lc) * onfactor;
-         else
-            {
-            aux_lc = aux_rc = 1.0F;
-            aux_flux = !aux_on;
-            }
-         }   
-      else
-         {
-         if (aux_lc > lower)
-            aux_lc = aux_rc -= aux_lc * offfactor;
-         else
-            {
-            aux_lc = aux_rc = 0.0F;
-            aux_flux = aux_on;
-            }
-         }
-      }
-   }
-
 /* process_audio: the JACK callback routine */
 void process_audio(jack_nframes_t nframes)
    {
@@ -536,6 +499,7 @@ void process_audio(jack_nframes_t nframes)
    static float df = 1.0;       /* the ducking factor - generated by the compressor */
    /* the following are used to calculate the microphone mix */
    sample_t lc_s_micmix = 0.0f, rc_s_micmix = 0.0f, d_micmix = 0.0f;
+   sample_t lc_s_auxmix = 0.0f, rc_s_auxmix = 0.0f;
    /* the following are used to apply the output of the compressor code to the audio levels */
    sample_t compressor_gain = 1.0, str_normalizer_gain;
    /* a counter variable used to trigger the volume smoothing on a regular basis */
@@ -543,9 +507,9 @@ void process_audio(jack_nframes_t nframes)
    /* index values for reading from a table of fade gain values */
    static jack_nframes_t alarm_index = 0;
    /* pointers to buffers provided by JACK */
-   sample_t *lap, *rap, *lsp, *rsp, *lxp, *rxp, *lpsp, *rpsp, *lprp, *rprp;
+   sample_t *lap, *rap, *lsp, *rsp, *lpsp, *rpsp, *lprp, *rprp;
    sample_t *la_buffer, *ra_buffer, *ls_buffer, *rs_buffer, *lps_buffer, *rps_buffer;
-   sample_t *dolp, *dorp, *dilp, *dirp, *dol_buffer, *dor_buffer, *dil_buffer, *dir_buffer;
+   sample_t *dolp, *dorp, *dilp, *dirp;
    /* ponters to buffers for reading the media players */
    sample_t *lplcp, *lprcp, *rplcp, *rprcp, *jplcp, *jprcp, *iplcp, *iprcp;
    /* pointers to buffers for fading */
@@ -633,16 +597,14 @@ void process_audio(jack_nframes_t nframes)
    ra_buffer = rap = (sample_t *) jack_port_get_buffer (audio_right_port, nframes);
    ls_buffer = lsp = (sample_t *) jack_port_get_buffer (stream_left_port, nframes);
    rs_buffer = rsp = (sample_t *) jack_port_get_buffer (stream_right_port, nframes);
-   dol_buffer = dolp = (sample_t *) jack_port_get_buffer (dspout_left_port, nframes);
-   dor_buffer = dorp = (sample_t *) jack_port_get_buffer (dspout_right_port, nframes);
-   dil_buffer = dilp = (sample_t *) jack_port_get_buffer (dspin_left_port, nframes);
-   dir_buffer = dirp = (sample_t *) jack_port_get_buffer (dspin_right_port, nframes);
    lps_buffer = lpsp = (sample_t *) jack_port_get_buffer (phone_left_send, nframes);
    rps_buffer = rpsp = (sample_t *) jack_port_get_buffer (phone_right_send, nframes);
-   lxp = (sample_t *) jack_port_get_buffer (aux_left_channel, nframes);
-   rxp = (sample_t *) jack_port_get_buffer (aux_right_channel, nframes);
    lprp = (sample_t *) jack_port_get_buffer (phone_left_recv, nframes);
    rprp = (sample_t *) jack_port_get_buffer (phone_right_recv, nframes);
+   dolp = (sample_t *) jack_port_get_buffer (dspout_left_port, nframes);
+   dorp = (sample_t *) jack_port_get_buffer (dspout_right_port, nframes);
+   dilp = (sample_t *) jack_port_get_buffer (dspin_left_port, nframes);
+   dirp = (sample_t *) jack_port_get_buffer (dspin_right_port, nframes);
    
    /* recreate buffers for data read from the pipes via the jack ringbuffer */
    lp_lc = lplcp = irealloc(lp_lc, nframes);
@@ -746,18 +708,20 @@ void process_audio(jack_nframes_t nframes)
       {
       memset(lps_buffer, 0, nframes * sizeof (sample_t)); /* send silence to VOIP */
       memset(rps_buffer, 0, nframes * sizeof (sample_t));
-      for(samples_todo = nframes; samples_todo--; lap++, rap++, lsp++, rsp++, lxp++, rxp++,
+      for(samples_todo = nframes; samples_todo--; lap++, rap++, lsp++, rsp++,
                 lplcp++, lprcp++, rplcp++, rprcp++, jplcp++, jprcp++, iplcp++, iprcp++, dilp++, dirp++, dolp++, dorp++)
          {       
          if (vol_smooth_count++ % 100 == 0) /* Can change volume level every so many samples */
             update_smoothed_volumes();
          
          df = mic_process_all(mics) * dfmod;
-         for (micp = mics, lc_s_micmix = rc_s_micmix = d_micmix = 0.0f; *micp; micp++)
+         for (micp = mics, lc_s_micmix = rc_s_micmix = lc_s_auxmix = rc_s_auxmix = d_micmix = 0.0f; *micp; micp++)
             {
-            lc_s_micmix += (*micp)->lcm;
-            rc_s_micmix += (*micp)->rcm;
-            d_micmix += (*micp)->unpmdj;
+            lc_s_micmix += (*micp)->mlcm;
+            rc_s_micmix += (*micp)->mrcm;
+            lc_s_auxmix += (*micp)->alcm;
+            rc_s_auxmix += (*micp)->arcm;
+            d_micmix += (*micp)->munpmdj;
             }
        
          /* ducking calculation - disabled mics have df of 1.0 always */
@@ -802,9 +766,6 @@ void process_audio(jack_nframes_t nframes)
          else
             ip_lc_fade = ip_rc_fade = 0.0;
             
-         if (aux_flux)
-            update_mic_and_aux();               /* mic fade in/out */
-            
          if (fabs(*lplcp) > left_peak)          /* peak levels used for song cut-off */
             left_peak = fabs(*lplcp);
          if (fabs(*lprcp) > left_peak)
@@ -815,9 +776,9 @@ void process_audio(jack_nframes_t nframes)
             right_peak = fabs(*rprcp);
          
          /* This is it folks, the main mix */
-         *dolp = ((*lplcp * lp_lc_str) + (*rplcp * rp_lc_str) + (*lxp * aux_lc) + (*jplcp * jp_lc_str)) * df + lc_s_micmix + (*iplcp * ip_lc_str) + (ip_lc_fade * ip_lc_strf) + 
+         *dolp = ((*lplcp * lp_lc_str) + (*rplcp * rp_lc_str) + (*jplcp * jp_lc_str)) * df + lc_s_micmix + lc_s_auxmix + (*iplcp * ip_lc_str) + (ip_lc_fade * ip_lc_strf) + 
          (lp_lc_fade * lp_lc_strf) + (rp_lc_fade * rp_lc_strf) + (jp_lc_fade * jp_lc_strf);
-         *dorp = ((*lprcp * lp_rc_str) + (*rprcp * rp_rc_str) + (*rxp * aux_rc) + (*jprcp * jp_rc_str)) * df + rc_s_micmix + (*iprcp * ip_rc_str) + (ip_rc_fade * ip_rc_strf) +
+         *dorp = ((*lprcp * lp_rc_str) + (*rprcp * rp_rc_str) + (*jprcp * jp_rc_str)) * df + rc_s_micmix + rc_s_auxmix + (*iprcp * ip_rc_str) + (ip_rc_fade * ip_rc_strf) +
          (lp_rc_fade * lp_rc_strf) + (rp_rc_fade * rp_rc_strf) + (jp_rc_fade * jp_rc_strf);
          
          /* apply normalization */
@@ -852,9 +813,9 @@ void process_audio(jack_nframes_t nframes)
 
          if (stream_monitor == FALSE)
             {
-            *lap = ((*lplcp * lp_lc_aud) + (*rplcp * rp_lc_aud) + (*jplcp * jp_lc_aud)) * df + d_micmix + (*iplcp * ip_lc_aud) + (ip_lc_fade * ip_lc_aud) +
+            *lap = ((*lplcp * lp_lc_aud) + (*rplcp * rp_lc_aud) + (*jplcp * jp_lc_aud)) * df + d_micmix + lc_s_auxmix + (*iplcp * ip_lc_aud) + (ip_lc_fade * ip_lc_aud) +
             (lp_lc_fade * lp_lc_audf) + (rp_lc_fade * rp_lc_audf) + (jp_lc_fade * jp_lc_audf);
-            *rap = ((*lprcp * lp_rc_aud) + (*rprcp * rp_rc_aud) + (*jprcp * jp_rc_aud)) * df + d_micmix + (*iprcp * ip_rc_aud) + (ip_rc_fade * ip_rc_aud) +
+            *rap = ((*lprcp * lp_rc_aud) + (*rprcp * rp_rc_aud) + (*jprcp * jp_rc_aud)) * df + d_micmix + rc_s_auxmix + (*iprcp * ip_rc_aud) + (ip_rc_fade * ip_rc_aud) +
             (lp_rc_fade * lp_rc_audf) + (rp_rc_fade * rp_rc_audf) + (jp_rc_fade * jp_rc_audf);
             compressor_gain = db2level(limiter(&audio_limiter, *lap, *rap));
             *lap *= compressor_gain;
@@ -904,7 +865,7 @@ void process_audio(jack_nframes_t nframes)
    else
       if (simple_mixer == FALSE && mixermode == PHONE_PUBLIC)
          {
-         for(samples_todo = nframes; samples_todo--; lap++, rap++, lsp++, rsp++, lxp++, rxp++,
+         for(samples_todo = nframes; samples_todo--; lap++, rap++, lsp++, rsp++,
                 lplcp++, lprcp++, rplcp++, rprcp++, jplcp++, jprcp++,
                 lpsp++, rpsp++, lprp++, rprp++, iplcp++, iprcp++, dilp++, dirp++, dolp++, dorp++)
             {    
@@ -912,18 +873,17 @@ void process_audio(jack_nframes_t nframes)
                update_smoothed_volumes();
          
             mic_process_all(mics);
-            for (micp = mics, lc_s_micmix = rc_s_micmix = d_micmix = 0.0f; *micp; micp++)
+            for (micp = mics, lc_s_micmix = rc_s_micmix = lc_s_auxmix = rc_s_auxmix = d_micmix = 0.0f; *micp; micp++)
                {
-               /* All microphones to be soft unmuted by the user interface
-                * no muting of the dj mix to ensure a full conference takes place.
-                */
-               lc_s_micmix += (*micp)->lcm;
-               rc_s_micmix += (*micp)->rcm;
-               d_micmix += (*micp)->unpm;
+               lc_s_micmix += (*micp)->mlcm;
+               rc_s_micmix += (*micp)->mrcm;
+               lc_s_auxmix += (*micp)->alcm;
+               rc_s_auxmix += (*micp)->arcm;
+               d_micmix += (*micp)->munpm;
                }
 
-            /* No ducking */
-            df = 1.0;
+            /* No ducking but headroom still must apply */
+            df = db2level(current_headroom);
             
             if (plr_l->fadeindex < FB_SIZE)
                {
@@ -965,9 +925,6 @@ void process_audio(jack_nframes_t nframes)
             *lpsp = lc_s_micmix + (*jplcp * jp_lc_str) + (jp_lc_fade * jp_lc_strf);
             *rpsp = rc_s_micmix + (*jprcp * jp_rc_str) + (jp_rc_fade * jp_rc_strf);
             
-            if (aux_flux)
-               update_mic_and_aux();            /* smooth mic rise and fall mute/unmute */
-
             if (fabs(*lplcp) > left_peak)               /* peak levels used for song cut-off */
                left_peak = fabs(*lplcp);
             if (fabs(*lprcp) > left_peak)
@@ -978,9 +935,9 @@ void process_audio(jack_nframes_t nframes)
                right_peak = fabs(*rprcp);
 
             /* The main mix */
-            *dolp = ((*lplcp * lp_lc_str) + (*rplcp * rp_lc_str) + (*lxp * aux_lc)) + *lprp + *lpsp +
+            *dolp = ((*lplcp * lp_lc_str) + (*rplcp * rp_lc_str)) * df + *lprp + *lpsp + lc_s_auxmix +
             (lp_lc_fade * lp_rc_strf) + (rp_lc_fade * rp_lc_strf) + (*iplcp * ip_lc_str) + (ip_lc_fade * ip_lc_strf);
-            *dorp = ((*lprcp * lp_rc_str) + (*rprcp * rp_rc_str) + (*rxp * aux_rc)) + *rprp + *rpsp +
+            *dorp = ((*lprcp * lp_rc_str) + (*rprcp * rp_rc_str)) * df + *rprp + *rpsp + rc_s_auxmix +
             (lp_rc_fade * lp_rc_strf) + (rp_rc_fade * rp_rc_strf) + (*iprcp * ip_rc_str) + (ip_rc_fade * ip_rc_strf);
             
             compressor_gain = db2level(limiter(&phone_limiter, *lpsp, *rpsp));
@@ -1019,9 +976,9 @@ void process_audio(jack_nframes_t nframes)
 
             if (stream_monitor == FALSE)
                {
-               *lap = ((*lplcp * lp_lc_aud) + (*rplcp * rp_lc_aud)) + *lprp +
+               *lap = ((*lplcp * lp_lc_aud) + (*rplcp * rp_lc_aud)) * df + *lprp + lc_s_auxmix +
                (lp_lc_fade * lp_rc_audf) + (rp_lc_fade * rp_lc_audf) + (*iplcp * ip_lc_aud) + (ip_lc_fade * ip_lc_audf) + d_micmix + (*jplcp * jp_lc_str) + (jp_lc_fade * jp_lc_strf);
-               *rap = ((*lprcp * lp_rc_aud) + (*rprcp * rp_rc_aud)) + *rprp +
+               *rap = ((*lprcp * lp_rc_aud) + (*rprcp * rp_rc_aud)) * df + *rprp + rc_s_auxmix +
                (lp_rc_fade * lp_rc_audf) + (rp_rc_fade * rp_rc_audf) + (*iprcp * ip_rc_aud) + (ip_rc_fade * ip_rc_audf) + d_micmix + (*jprcp * jp_rc_str) + (jp_rc_fade * jp_rc_strf);
                compressor_gain = db2level(limiter(&audio_limiter, *lap, *rap));
                *lap *= compressor_gain;
@@ -1068,7 +1025,7 @@ void process_audio(jack_nframes_t nframes)
       else
          if (simple_mixer == FALSE && mixermode == PHONE_PRIVATE && mic_on == 0)
             {
-            for(samples_todo = nframes; samples_todo--; lap++, rap++, lsp++, rsp++, lxp++, rxp++,
+            for(samples_todo = nframes; samples_todo--; lap++, rap++, lsp++, rsp++,
             lplcp++, lprcp++, rplcp++, rprcp++, jplcp++, jprcp++, lpsp++, rpsp++, 
             lprp++, rprp++, iplcp++, iprcp++, dilp++, dirp++, dolp++, dorp++)
                {         
@@ -1076,12 +1033,13 @@ void process_audio(jack_nframes_t nframes)
                   update_smoothed_volumes();
 
                mic_process_all(mics);
-               for (micp = mics, lc_s_micmix = rc_s_micmix = d_micmix = 0.0f; *micp; micp++)
+               for (micp = mics, lc_s_micmix = rc_s_micmix = lc_s_auxmix = rc_s_auxmix = d_micmix = 0.0f; *micp; micp++)
                   {
-                  /* no muting of the dj mix to ensure a full conference takes place */
-                  lc_s_micmix += (*micp)->lc;
-                  rc_s_micmix += (*micp)->rc;
-                  d_micmix += (*micp)->unpm;
+                  lc_s_micmix += (*micp)->mlc;
+                  rc_s_micmix += (*micp)->mrc;
+                  lc_s_auxmix += (*micp)->alcm;
+                  rc_s_auxmix += (*micp)->arcm;
+                  d_micmix += (*micp)->munpm;
                   }
                
                /* No ducking */
@@ -1123,9 +1081,6 @@ void process_audio(jack_nframes_t nframes)
                else
                   ip_lc_fade = ip_rc_fade = 0.0;
 
-               if (aux_flux)
-                  update_mic_and_aux();         /* smooth mic rise and fall mute/unmute */
-               
                if (fabs(*lplcp) > left_peak)            /* peak levels used for song cut-off */
                   left_peak = fabs(*lplcp);
                if (fabs(*lprcp) > left_peak)
@@ -1136,9 +1091,9 @@ void process_audio(jack_nframes_t nframes)
                   right_peak = fabs(*rprcp);
                
                /* This is it folks, the main mix */
-               *dolp = (*lplcp * lp_lc_str) + (*rplcp * rp_lc_str) + (*lxp * aux_lc) +
+               *dolp = (*lplcp * lp_lc_str) + (*rplcp * rp_lc_str) + lc_s_auxmix + 
                (lp_lc_fade * lp_rc_strf) + (rp_lc_fade * rp_lc_strf) + (*iplcp * ip_lc_str) + (ip_lc_fade * ip_lc_strf);
-               *dorp = (*lprcp * lp_rc_str) + (*rprcp * rp_rc_str) + (*rxp * aux_rc) +
+               *dorp = (*lprcp * lp_rc_str) + (*rprcp * rp_rc_str) + rc_s_auxmix +
                (lp_rc_fade * lp_rc_strf) + (rp_rc_fade * rp_rc_strf) + (*iprcp * ip_rc_str) + (ip_rc_fade * ip_rc_strf);
                
                /* apply normalization at the stream level */
@@ -1182,8 +1137,8 @@ void process_audio(jack_nframes_t nframes)
 
                if (stream_monitor == FALSE) /* the DJ can hear the VOIP phone call */
                   {
-                  *lap = (*lsp * mb_lc_aud) + (*jplcp * jp_lc_aud) + d_micmix + (jp_lc_fade * jp_lc_strf) + *lprp;
-                  *rap = (*rsp * mb_lc_aud) + (*jprcp * jp_rc_aud) + d_micmix + (jp_rc_fade * jp_rc_strf) + *rprp;
+                  *lap = (*lsp * mb_lc_aud) + (*jplcp * jp_lc_aud) + d_micmix + (lc_s_auxmix *mb_lc_aud) + (jp_lc_fade * jp_lc_strf) + *lprp;
+                  *rap = (*rsp * mb_lc_aud) + (*jprcp * jp_rc_aud) + d_micmix + (rc_s_auxmix *mb_rc_aud) + (jp_rc_fade * jp_rc_strf) + *rprp;
                   compressor_gain = db2level(limiter(&audio_limiter, *lap, *rap));
                   *lap *= compressor_gain;
                   *rap *= compressor_gain;
@@ -1229,7 +1184,7 @@ void process_audio(jack_nframes_t nframes)
          else
             if (simple_mixer == FALSE && mixermode == PHONE_PRIVATE) /* note: mic is on */
                {
-               for(samples_todo = nframes; samples_todo--; lap++, rap++, lsp++, rsp++, lxp++, rxp++,
+               for(samples_todo = nframes; samples_todo--; lap++, rap++, lsp++, rsp++, 
                      lplcp++, lprcp++, rplcp++, rprcp++, jplcp++, jprcp++, lpsp++, rpsp++,
                         iplcp++, iprcp++, dilp++, dirp++, dolp++, dorp++)
                   {
@@ -1237,11 +1192,13 @@ void process_audio(jack_nframes_t nframes)
                      update_smoothed_volumes();
 
                   df = mic_process_all(mics) * dfmod;
-                  for (micp = mics, lc_s_micmix = rc_s_micmix = d_micmix = 0.0f; *micp; micp++)
+                  for (micp = mics, lc_s_micmix = rc_s_micmix = lc_s_auxmix = rc_s_auxmix = d_micmix = 0.0f; *micp; micp++)
                      {
-                     lc_s_micmix += (*micp)->lcm;
-                     rc_s_micmix += (*micp)->rcm;
-                     d_micmix += (*micp)->unpmdj;
+                     lc_s_micmix += (*micp)->mlcm;
+                     rc_s_micmix += (*micp)->mrcm;
+                     lc_s_auxmix += (*micp)->alcm;
+                     rc_s_auxmix += (*micp)->arcm;
+                     d_micmix += (*micp)->munpmdj;
                      }
 
                   /* ducking calculation - disabled mics have df of 1.0 always */
@@ -1286,9 +1243,6 @@ void process_audio(jack_nframes_t nframes)
                   else
                      ip_lc_fade = ip_rc_fade = 0.0;
 
-                  if (aux_flux)
-                     update_mic_and_aux();      /* smooth mic rise and fall mute/unmute */
-
                   if (fabs(*lplcp) > left_peak)         /* peak levels used for song cut-off */
                      left_peak = fabs(*lplcp);
                   if (fabs(*lprcp) > left_peak)
@@ -1299,9 +1253,9 @@ void process_audio(jack_nframes_t nframes)
                      right_peak = fabs(*rprcp);
 
                   /* This is it folks, the main mix */
-                  *dolp = ((*lplcp * lp_lc_str) + (*rplcp * rp_lc_str) + (*lxp * aux_lc) + (*jplcp * jp_lc_str)) * df + lc_s_micmix + (*iplcp * ip_lc_str) + (ip_lc_fade * ip_lc_strf) +
+                  *dolp = ((*lplcp * lp_lc_str) + (*rplcp * rp_lc_str) + (*jplcp * jp_lc_str)) * df + lc_s_micmix + lc_s_auxmix + (*iplcp * ip_lc_str) + (ip_lc_fade * ip_lc_strf) +
                   (lp_lc_fade * lp_lc_strf) + (rp_lc_fade * rp_lc_strf) + (jp_lc_fade * jp_lc_strf);
-                  *dorp = ((*lprcp * lp_rc_str) + (*rprcp * rp_rc_str) + (*rxp * aux_rc) + (*jprcp * jp_rc_str)) * df + rc_s_micmix + (*iprcp * ip_rc_str) + (ip_rc_fade * ip_rc_strf) +
+                  *dorp = ((*lprcp * lp_rc_str) + (*rprcp * rp_rc_str) + (*jprcp * jp_rc_str)) * df + rc_s_micmix + rc_s_auxmix + (*iprcp * ip_rc_str) + (ip_rc_fade * ip_rc_strf) +
                   (lp_rc_fade * lp_rc_strf) + (rp_rc_fade * rp_rc_strf) + (jp_rc_fade * jp_rc_strf);
                   
                   /* apply normalization at the stream level */
@@ -1339,9 +1293,9 @@ void process_audio(jack_nframes_t nframes)
 
                   if (stream_monitor == FALSE)
                      {
-                     *lap = ((*lplcp * lp_lc_aud) + (*rplcp * rp_lc_aud) + (*jplcp * jp_lc_aud)) * df + d_micmix + (*iplcp * ip_lc_aud) + (ip_lc_fade * ip_lc_audf) +
+                     *lap = ((*lplcp * lp_lc_aud) + (*rplcp * rp_lc_aud) + (*jplcp * jp_lc_aud)) * df + d_micmix + lc_s_auxmix + (*iplcp * ip_lc_aud) + (ip_lc_fade * ip_lc_audf) +
                      (lp_lc_fade * lp_lc_audf) + (rp_lc_fade * rp_lc_audf) + (jp_lc_fade * jp_lc_audf);
-                     *rap = ((*lprcp * lp_rc_aud) + (*rprcp * rp_rc_aud) + (*jprcp * jp_rc_aud)) * df + d_micmix + (*iprcp * ip_rc_aud) + (ip_rc_fade * ip_rc_audf) +
+                     *rap = ((*lprcp * lp_rc_aud) + (*rprcp * rp_rc_aud) + (*jprcp * jp_rc_aud)) * df + d_micmix + rc_s_auxmix + (*iprcp * ip_rc_aud) + (ip_rc_fade * ip_rc_audf) +
                      (lp_rc_fade * lp_rc_audf) + (rp_rc_fade * rp_rc_audf) + (jp_rc_fade * jp_rc_audf);
                      compressor_gain = db2level(limiter(&audio_limiter, *lap, *rap));
                      *lap *= compressor_gain;
@@ -1549,15 +1503,14 @@ int main(int argc, char **argv)
    float normrise, normfall;
    int fadeout_f;
    int flush_left, flush_right, flush_jingles, flush_interlude;
-   int i, new_left_pause, new_right_pause;
-   static int old_aux_on = 0;
+   int new_left_pause, new_right_pause;
    jack_nframes_t nframes;
    char *artist = NULL, *title = NULL, *album = NULL, *replaygain = NULL;
    double length;
    int sync = FALSE;
    int use_dsp;
    jack_status_t status;
-   char *server_name = getenv("IDJC_JACK_SERVER");
+   char *server_name = getenv("jack_server_name");
    char midi_output[MIDI_QUEUE_SIZE];
    char *our_sc_str_in_l;
    char *our_sc_str_in_r;
@@ -1609,11 +1562,6 @@ int main(int argc, char **argv)
                                         JackPortIsOutput, 0);
    stream_right_port = jack_port_register(client, "str_out_r", JACK_DEFAULT_AUDIO_TYPE, 
                                         JackPortIsOutput, 0);
-   /* intended as a spare for connection to almost any jack app you like */
-   aux_left_channel = jack_port_register(client, "aux_in_l", JACK_DEFAULT_AUDIO_TYPE,
-                                        JackPortIsInput, 0);
-   aux_right_channel = jack_port_register(client, "aux_in_r", JACK_DEFAULT_AUDIO_TYPE,
-                                        JackPortIsInput, 0);
    /* inteneded for connection to a VOIP application */
    phone_left_send = jack_port_register(client, "voip_out_l", JACK_DEFAULT_AUDIO_TYPE,
                                         JackPortIsOutput, 0);
@@ -1683,7 +1631,7 @@ int main(int argc, char **argv)
    else
       {
       alarm_size = (sr / 900) * 900;    /* builds the alarm tone wave table */
-      for (i = 0; i < alarm_size ; i++) /* note it has a nice 2nd harmonic added */
+      for (unsigned i = 0; i < alarm_size ; i++) /* note it has a nice 2nd harmonic added */
          {
          eot_alarm_table[i] = 0.83F * sinf((i % (sr/900)) * 6.283185307F / (sr/900));
          eot_alarm_table[i] += 0.024F * sinf((i % (sr/900)) * 12.56637061F / (sr/900) + 3.141592654F / 4.0F);
@@ -1704,7 +1652,7 @@ int main(int argc, char **argv)
       plr_i->fadeindex = FB_SIZE;
 
       float f = powf(10.0f, -441.0f/((FB_SIZE) * 200.0f));
-      for (i = 0; i < FB_SIZE; i++)
+      for (unsigned i = 0; i < FB_SIZE; i++)
          fade_table[i] = powf(f, i);
       }
 
@@ -1794,6 +1742,11 @@ int main(int argc, char **argv)
          mic_valueparse(mics[atoi(item_index)], mic_param);
          }
 
+      if (!strcmp(action, "new_channel_mode_string"))
+         {
+         mic_set_role_all(mics, channel_mode_string);
+         }
+
       if (!strcmp(action, "headroom"))
          {
          headroom_db = strtof(headroom, NULL);
@@ -1919,10 +1872,10 @@ int main(int argc, char **argv)
       if (!strcmp(action, "mixstats"))
          {
          if(sscanf(mixer_string,
-                ":%03d:%03d:%03d:%03d:%03d:%03d:%d:%1d%1d%1d%1d%1d:%1d%1d:%1d:%1d%1d%1d%1d:%1d:%1d:%1d:%1d:%1d:%f:%f:%1d:%f:%d:%d:%d:",
-                &volume, &volume2, &crossfade, &jinglesvolume, &interludevol, &mixbackvol, &jingles_playing,
+                ":%03d:%03d:%03d:%03d:%03d:%03d:%03d:%d:%1d%1d%1d%1d%1d:%1d%1d:%1d%1d%1d%1d:%1d:%1d:%1d:%1d:%1d:%f:%f:%1d:%f:%d:%d:%d:",
+                &volume, &volume2, &crossfade, &jinglesvolume, &jinglesvolume2 , &interludevol, &mixbackvol, &jingles_playing,
                 &left_stream, &left_audio, &right_stream, &right_audio, &stream_monitor,
-                &new_left_pause, &new_right_pause, &aux_on, &flush_left, &flush_right, &flush_jingles, &flush_interlude, &simple_mixer, &eot_alarm_set, &mixermode, &fadeout_f, &main_play, &(plr_l->newpbspeed), &(plr_r->newpbspeed), &speed_variance, &dj_audio_level, &crosspattern, &use_dsp, &twodblimit) !=31)
+                &new_left_pause, &new_right_pause, &flush_left, &flush_right, &flush_jingles, &flush_interlude, &simple_mixer, &eot_alarm_set, &mixermode, &fadeout_f, &main_play, &(plr_l->newpbspeed), &(plr_r->newpbspeed), &speed_variance, &dj_audio_level, &crosspattern, &use_dsp, &twodblimit) !=31)
             {
             fprintf(stderr, "mixer got bad mixer string\n");
             break;
@@ -1949,10 +1902,6 @@ int main(int argc, char **argv)
             else
                xlplayer_unpause(plr_r);
             }
-
-         if (aux_on != old_aux_on)
-            aux_flux = TRUE;
-         old_aux_on = aux_on;
          }
       /* the means by which the jack ports are connected to the soundcard */
       /* notably the main app requests the connections */
@@ -2026,18 +1975,6 @@ int main(int argc, char **argv)
                if (outport && outport[1] && outport[2] && outport[3])
                   jack_connect(client, jack_port_name(stream_right_port), outport[3]);
          }
-      if (!strcmp(action, "remakeauxl"))
-         {
-         jack_port_disconnect(client, aux_left_channel);
-         if (auxl[0] != '\0')
-            jack_connect(client, auxl, jack_port_name(aux_left_channel));
-         }
-      if (!strcmp(action, "remakeauxr"))
-         {
-         jack_port_disconnect(client, aux_right_channel);
-         if (auxr[0] != '\0')
-            jack_connect(client, auxr, jack_port_name(aux_right_channel));
-         }
       if (!strcmp(action, "remakemidi"))
          {
          jack_port_disconnect(client, midi_port);
@@ -2120,6 +2057,8 @@ int main(int argc, char **argv)
                    "left_additional_metadata=%d\n"
                    "right_additional_metadata=%d\n"
                    "midi=%s\n"
+                   "silence_l=%f\n"
+                   "silence_r=%f\n"
                    "end\n",
                    str_l_peak_db, str_r_peak_db,
                    str_l_rms_db, str_r_rms_db,
@@ -2139,7 +2078,9 @@ int main(int argc, char **argv)
                    right_audio_runout && (!(plr_r->current_audio_context & 0x1)),
                    plr_l->dynamic_metadata.data_type,
                    plr_r->dynamic_metadata.data_type,
-                   midi_output);
+                   midi_output,
+                   plr_l->silence,
+                   plr_r->silence);
                    
          /* tell the jack mixer it can reset its vu stats now */
          reset_vu_stats_f = TRUE;
