@@ -30,78 +30,30 @@
 
 typedef jack_default_audio_sample_t sample_t;
 
-static void live_ogg_build_metadata(struct encoder *encoder, struct loe_data *s)
+void live_ogg_capture_metadata(struct encoder *e, struct ogg_tag_data *t)
    {
-   char *r, *w, *e, *marker;    /* read, write, end, the placemarker string */
-   int count;   /* the number of occurrences of marker in metaformat */
-   int len;     /* the length of the substitute string */
-   size_t size;
+   live_ogg_free_metadata(t);
 
-   if (s->artist)
-      free(s->artist);
-   if (s->title)
-      free(s->title);
-   pthread_mutex_lock(&encoder->metadata_mutex);
-   for (count = 0, r = encoder->metaformat; (r = strstr(r, "%s")); count++, r += 2);
-   if (count == 0)
-      {
-      /* handle metadata does not contain artist - title */
-      s->artist = NULL;
-      if (encoder->metaformat && encoder->metaformat[0] != '\0')
-         s->title = strdup(encoder->metaformat);
-      else
-         s->title = NULL;
-      }
-   else
-      {
-      /* handle metadata only contains artist - title */
-      if (count == 1 && !strcmp(encoder->metaformat, "%s"))
-         {
-         if (encoder->artist && encoder->artist[0] != '\0')
-            s->artist = strdup(encoder->artist);
-         else
-            s->artist = NULL;
-         if (encoder->title && encoder->title[0] != '\0')
-            s->title = strdup(encoder->title);
-         else
-            s->title = NULL;
-         }
-      else
-         {
-         /* handle a mix of possible multiple "artist - title" and or other text */
-         /* in python: artist = metaformat.replace("%s", artist_title) */
-         /* in C see below LOL */
-         s->title = malloc(size = count * strlen(encoder->artist_title) + strlen(encoder->metaformat) - count * strlen(marker = "%s") + 1);
-         if (!s->title)
-            fprintf(stderr, "live_ogg_build_metadata: malloc failure\n");
-         else
-            {
-            len = strlen(encoder->artist_title);
-            r = encoder->metaformat;
-            w = s->title;
-            for (;;)
-               {
-               if ((e = strstr(r, marker)))
-                  {
-                  memcpy(w, r, e - r);  /* copy the text before the %s */
-                  w += e - r;           /* advance write pointer */
-                  memcpy(w, encoder->artist_title, len); /* copy artist - title */
-                  w += len;             /* advance the write pointer */
-                  r = e + 2;            /* skip over the %s */
-                  }
-               else
-                  {
-                  strcpy(w, r); /* copy the remaining text and null terminate */
-                  break;        /* finished */
-                  }
-               }
-            }
-         s->artist = NULL;
-         }
-      }
-   encoder->new_metadata = FALSE;
-   pthread_mutex_unlock(&encoder->metadata_mutex);
-   fprintf(stderr, "live_ogg_build_metadata: metadata for encoder %d\nartist=%s\ntitle=%s\n", encoder->numeric_id, s->artist, s->title);
+   pthread_mutex_lock(&e->metadata_mutex);
+   t->custom = strdup(e->custom_meta);
+   t->artist = strdup(e->artist);
+   t->title  = strdup(e->title);
+   t->album  = strdup(e->album);
+   e->new_metadata = FALSE;
+   pthread_mutex_unlock(&e->metadata_mutex);
+   }
+
+void live_ogg_free_metadata(struct ogg_tag_data *t)
+   {
+   if (t->custom)
+      free(t->custom);
+   if (t->artist)
+      free(t->artist);
+   if (t->title)
+      free(t->title);
+   if (t->album)
+      free(t->album);
+   memset(t, '\0', sizeof (struct ogg_tag_data));
    }
 
 int live_ogg_write_packet(struct encoder *encoder, ogg_page *op, int flags)
@@ -139,6 +91,7 @@ static void live_ogg_encoder_main(struct encoder *encoder)
    int cycle_restart = FALSE, cycle_restart2 = FALSE, packet_flags = PF_INITIAL | PF_OGG | PF_HEADER;
    float **buffer;
    ogg_int64_t oldgranulepos;
+   struct ogg_tag_data *t = &s->tag_data;
    
    if (encoder->encoder_state == ES_STARTING)
       {
@@ -169,11 +122,27 @@ static void live_ogg_encoder_main(struct encoder *encoder)
       vorbis_comment_init(&s->vc);
       /* this function takes raw metadata and does something type specific with it */
       if (encoder->new_metadata)
-         live_ogg_build_metadata(encoder, encoder->encoder_private);
-      if (s->artist)
-         vorbis_comment_add_tag(&s->vc, "ARTIST", s->artist);
-      if (s->title)
-         vorbis_comment_add_tag(&s->vc, "TITLE", s->title);
+         live_ogg_capture_metadata(encoder, t);
+      
+      if (t->custom && t->custom[0])
+         {
+         vorbis_comment_add_tag(&s->vc, "TITLE", t->custom);
+         if (t->artist && t->artist[0])
+            vorbis_comment_add_tag(&s->vc, "TRK-ARTIST", t->artist);
+         if (t->title && t->title[0])
+            vorbis_comment_add_tag(&s->vc, "TRK-TITLE", t->title);
+         if (t->album && t->album[0])
+            vorbis_comment_add_tag(&s->vc, "TRK-ALBUM", t->album);
+         }
+      else
+         {
+         if (t->artist && t->artist[0])
+            vorbis_comment_add_tag(&s->vc, "ARTIST", t->artist);
+         if (t->title && t->title[0])
+            vorbis_comment_add_tag(&s->vc, "TITLE", t->title);
+         if (t->album && t->album[0])
+            vorbis_comment_add_tag(&s->vc, "ALBUM", t->album);
+         }
       vorbis_analysis_headerout(&s->vd, &s->vc, &header_main, &header_comments, &header_codebooks);
       ogg_stream_packetin(&s->os, &header_main);
       ogg_stream_packetin(&s->os, &header_comments);
@@ -278,6 +247,7 @@ static void live_ogg_encoder_main(struct encoder *encoder)
    encoder->run_encoder = NULL;
    encoder->flush = FALSE;
    encoder->encoder_private = NULL;
+   live_ogg_free_metadata(&s->tag_data);
    free(s);
    fprintf(stderr, "live_ogg_encoder_main: finished cleanup\n");
    return;
