@@ -50,31 +50,31 @@ static void mic_process_start(struct mic *self, jack_nframes_t nframes)
    if (mode_request != self->mode)
       {
       if (self->mode == 0)
-         fprintf(stderr, "activated mic %d\n", self->id);
+         fprintf(stderr, "activated ch %d\n", self->id);
          
       if (self->mode == 2)
          {
-         fprintf(stderr, "leaving fully processed mode, mic %d\n", self->id);
+         fprintf(stderr, "leaving fully processed mode, ch %d\n", self->id);
          agc_reset(self->agc);
          }
 
       if (mode_request == 3)
          {
-         fprintf(stderr, "entering stereo mode, mic %d\n", self->id);
+         fprintf(stderr, "entering stereo mode, ch %d\n", self->id);
          self->host = self->partner;
          agc_set_partnered_mode(self->agc, TRUE);
          }
 
       if (self->mode == 3)
          {
-         fprintf(stderr, "leaving stereo mode, mic %d\n", self->id);
+         fprintf(stderr, "leaving stereo mode, ch %d\n", self->id);
          self->host = self;
          agc_set_partnered_mode(self->agc, FALSE);
          }
 
       if (mode_request == 0)
          {
-         fprintf(stderr, "deactivated mic %d\n", self->id);
+         fprintf(stderr, "deactivated ch %d\n", self->id);
          self->open = 0;
          self->mute = 0.0f;
          self->unp = self->unpm = self->unpmdj = 0.0f;
@@ -144,6 +144,8 @@ static void mic_process_stage3(struct mic *self)
 
 static void mic_process_stage4(struct mic *self)
    {
+   float m = self->mic_g;
+   float a = self->aux_g;
    struct mic *host = self->host;   
       
    if (host->mode == 2)
@@ -162,6 +164,24 @@ static void mic_process_stage4(struct mic *self)
    float l = fabsf(self->lrc);
    if (l > self->peak)
       self->peak = l;
+      
+   self->munp = self->unp * m;
+   self->munpm = self->unpm * m;
+   self->munpmdj = self->unpmdj * m;
+   self->mlrc = self->lrc * m;
+   self->mlc = self->lc * m;
+   self->mrc = self->rc * m;
+   self->mlcm = self->lcm * m;
+   self->mrcm = self->rcm * m;
+
+   self->aunp = self->unp * a;
+   self->aunpm = self->unpm * a;
+   self->aunpmdj = self->unpmdj * a;
+   self->alrc = self->lrc * a;
+   self->alc = self->lc * a;
+   self->arc = self->rc * a;
+   self->alcm = self->lcm * a;
+   self->arcm = self->rcm * a;
    }
 
 float mic_process_all(struct mic **mics)
@@ -211,6 +231,26 @@ void mic_stats_all(struct mic **mics)
       mic_stats(*mics++);
    }
 
+static void mic_set_role(struct mic *self, int role)
+   {
+   if (role == 'm')
+      {
+      self->mic_g = 1.0f;
+      self->aux_g = 0.0f;
+      }
+   else // if role == 'a'
+      {
+      self->mic_g = 0.0f;
+      self->aux_g = 1.0f;
+      }
+   }
+
+void mic_set_role_all(struct mic **mics, const char *role)
+   {
+   while (*mics)
+      mic_set_role(*mics++, *role++);
+   }
+
 static struct mic *mic_init(jack_client_t *client, int sample_rate, int id)
    {
    struct mic *self;
@@ -226,6 +266,7 @@ static struct mic *mic_init(jack_client_t *client, int sample_rate, int id)
    self->id = id;
    self->sample_rate = (float)sample_rate;   
    self->pan = 50;
+   self->aux_g = 1.0f;
    self->peak = peak_init;
    if (!(self->agc = agc_init(sample_rate, 0.01161f, id)))
       {
@@ -233,7 +274,7 @@ static struct mic *mic_init(jack_client_t *client, int sample_rate, int id)
       free(self);
       return NULL;
       }
-   snprintf(port_name, 10, "mic_in_%d", id);  
+   snprintf(port_name, 10, "ch_in_%d", id);  
    self->jack_port = jack_port_register(client, port_name,
                      JACK_DEFAULT_AUDIO_TYPE, JackPortIsInput, 0); 
    calculate_gain_values(self);   
