@@ -76,11 +76,11 @@ int oggdec_get_next_packet(struct oggdec_vars *self)
    return 1;
    }
 
-static int vorbis_get_samplerate(struct oggdec_vars *self)  /* attempt to get ARTIST=, TITLE= also */
+static unsigned vorbis_get_samplerate(struct oggdec_vars *self)  /* attempt to get ARTIST=, TITLE= also */
    {
    vorbis_info vi;
    vorbis_comment vc;
-   int samplerate;
+   unsigned samplerate;
 
    vorbis_info_init(&vi);
    vorbis_comment_init(&vc);
@@ -173,7 +173,6 @@ static int vorbis_get_samplerate(struct oggdec_vars *self)  /* attempt to get AR
    
 #ifdef HAVE_OGGFLAC
 
-#ifdef FLAC_POST1_1_3
 FLAC__StreamDecoderReadStatus oggflac_read_callback(const FLAC__StreamDecoder *decoder, FLAC__byte buffer[], size_t *bytes, void *client_data)
    {
    struct oggdec_vars *self = client_data;
@@ -187,7 +186,7 @@ FLAC__StreamDecoderReadStatus oggflac_read_callback(const FLAC__StreamDecoder *d
    if (bytes_remaining < 0 || *bytes <= 0)
       return FLAC__STREAM_DECODER_READ_STATUS_ABORT;
 
-   if (*bytes > bytes_remaining)
+   if (*bytes > (size_t)bytes_remaining)
       *bytes = bytes_remaining;
 
    *bytes = fread(buffer, sizeof (FLAC__byte), *bytes, self->fp);
@@ -213,7 +212,7 @@ FLAC__StreamDecoderSeekStatus oggflac_seek_callback(const FLAC__StreamDecoder *d
    else
       end_bound = self->bos_offset[self->ix + 1] - start_bound;
 
-   if (absolute_byte_offset > end_bound - start_bound)
+   if (absolute_byte_offset > (FLAC__uint64)(end_bound - start_bound))
       {
       fprintf(stderr, "oggflac_seek_callback: seek error1\n");
       return FLAC__STREAM_DECODER_SEEK_STATUS_ERROR;
@@ -282,7 +281,7 @@ static void oggflac_metadata_callback(const FLAC__StreamDecoder *decoder, const
    struct oggdec_vars *self = client_data;
    const FLAC__StreamMetadata_StreamInfo *si;
    const FLAC__StreamMetadata_VorbisComment *vc;
-   int i, use_alt_tags;
+   int use_alt_tags;
    
    int match(char *t, char *comment)
       {
@@ -299,10 +298,9 @@ static void oggflac_metadata_callback(const FLAC__StreamDecoder *decoder, const
 
    void copy_tag(char *t, char **target, int multiple)
       {
-      int j;
       char *old, *new;
       
-      for (j = 0; j < vc->num_comments; j++)
+      for (unsigned j = 0; j < vc->num_comments; j++)
          {
          if (match(t, (char *)vc->comments[j].entry))
             {
@@ -336,7 +334,7 @@ static void oggflac_metadata_callback(const FLAC__StreamDecoder *decoder, const
          vc = &metadata->data.vorbis_comment;
          fprintf(stderr, "There are %u comment tags\n", (unsigned)vc->num_comments);
          use_alt_tags = FALSE;
-         for (i = 0; i < vc->num_comments; i++)
+         for (unsigned i = 0; i < vc->num_comments; i++)
             {
             if (match("trk-title", (char *)vc->comments[i].entry))
                use_alt_tags = TRUE;
@@ -384,14 +382,9 @@ void oggflac_error_callback(const FLAC__StreamDecoder *decoder, FLAC__StreamDeco
          fprintf(stderr, "oggflac_error_callback: flac decoder error, unknown error\n");
       }
    }
-#endif /* FLAC_POST1_1_3 */
 
 static int flac_get_samplerate(struct oggdec_vars *self)
    {
-#ifndef FLAC_POST1_1_3
-   fprintf(stderr, "flac_get_samplerate: obsolete FLAC API not supported on new features\n"); 
-   return 0;
-#else
    FLAC__StreamDecoder *decoder;
 
    if (!(decoder = FLAC__stream_decoder_new()))
@@ -407,7 +400,7 @@ static int flac_get_samplerate(struct oggdec_vars *self)
       oggflac_tell_callback, oggflac_length_callback,
       oggflac_eof_callback,  oggflac_write_callback,
       oggflac_metadata_callback, oggflac_error_callback,
-      self) != FLAC__STREAM_DECODER_SEARCH_FOR_METADATA)
+      self) != FLAC__STREAM_DECODER_INIT_STATUS_OK)
       {
       fprintf(stderr, "flac_get_samplerate: call to FLAC__stream_decoder_init_stream failed\n");
       FLAC__stream_decoder_delete(decoder);
@@ -418,7 +411,6 @@ static int flac_get_samplerate(struct oggdec_vars *self)
    FLAC__stream_decoder_delete(decoder);
 
    return self->samplerate[self->ix];
-#endif /* FLAC_POST1_1_3 */
    }
 #endif /* HAVE_OGGFLAC */
 
@@ -691,7 +683,7 @@ static off_t oggscan_eos(struct oggdec_vars *self, off_t offset, off_t offset_en
          /* make space for data about this logical stream */
          self->n_streams++;
          self->bos_offset = realloc(self->bos_offset, self->n_streams * sizeof (off_t));
-         self->granule_count = realloc(self->granule_count, self->n_streams * sizeof (int));
+         self->granule_count = realloc(self->granule_count, self->n_streams * sizeof (unsigned));
          self->samplerate = realloc(self->samplerate, self->n_streams * sizeof (int));
          self->channels = realloc(self->channels, self->n_streams * sizeof (int));
          self->serial = realloc(self->serial, self->n_streams * sizeof (int));
@@ -774,7 +766,8 @@ static struct oggdec_vars *oggdecode_get_metadata(char *pathname)
    off_t  offset = 0, offset_end, offset_new;
    size_t bytes;
    char  *buffer;
-   int i, samplerate = 0;
+   int i;
+   unsigned samplerate = 0;
    double start_time = 0.0;
    
    /* allocate storage space */
