@@ -306,6 +306,16 @@ int streamer_connect(struct threads_info *ti, struct universal_vars *uv, void *o
       sce("password");
       goto error;
       }
+   if (sv->useragent[0])
+      {
+      if (shout_set_agent(self->shout, sv->useragent) != SHOUTERR_SUCCESS)
+         {
+         sce("useragent");
+         goto error;
+         }
+      else
+         fprintf(stderr, "user agent is set\n");
+      }
    if (shout_set_name(self->shout, sv->dj_name) != SHOUTERR_SUCCESS)
       {
       sce("stream/dj name");
